/***************************************************************************
*   Copyright (C) 2003 by Sandro Giessl                                   *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qradiobutton.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qwhatsthis.h>

#include <kconfig.h>
#include <klocale.h>
#include <kglobal.h>

#include "config.h"
#include "configdialog.h"

KindustrialConfig::KindustrialConfig(KConfig* config, QWidget* parent)
    : QObject(parent), m_config(0), m_dialog(0)
{
    // create the configuration object
    m_config = new KConfig("kwinkindustrialrc");
    KGlobal::locale()->insertCatalogue("kwin_kindustrial_config");

    // create and show the configuration dialog
    m_dialog = new ConfigDialog(parent);
    m_dialog->show();

    // load the configuration
    load(config);

    // setup the connections
    connect(m_dialog->titleAlign, SIGNAL(clicked(int)),
            this, SIGNAL(changed()));
    connect(m_dialog->designatedTitlebarColor, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->titleShadow, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->shrinkBorders, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->titlebarHeight, SIGNAL(valueChanged(int)),
            this, SIGNAL(changed()));

}

KindustrialConfig::~KindustrialConfig()
{
    if (m_dialog) delete m_dialog;
    if (m_config) delete m_config;
}

void KindustrialConfig::load(KConfig*)
{
    m_config->setGroup("General");


    QString value = m_config->readEntry("TitleAlignment", "AlignHCenter");
    QRadioButton *button = (QRadioButton*)m_dialog->titleAlign->child(value);
    if (button) button->setChecked(true);
    bool designatedTitlebarColor = m_config->readBoolEntry("UseTitleBarColor", false);
    m_dialog->designatedTitlebarColor->setChecked(designatedTitlebarColor);
    bool titleShadow = m_config->readBoolEntry("TitleShadow", true);
    m_dialog->titleShadow->setChecked(titleShadow);
    bool shrinkBorders = m_config->readBoolEntry("ShrinkBorders", true);
    m_dialog->shrinkBorders->setChecked(shrinkBorders);
    int titlebarHeight = m_config->readNumEntry("TitleHeightMin", 19);
    if(titlebarHeight <= 16)
    {
        m_dialog->titlebarHeight->setValue(1);
    }
    else if(titlebarHeight <= 19)
    {
        m_dialog->titlebarHeight->setValue(2);
    }
    else if(titlebarHeight <= 23)
    {
        m_dialog->titlebarHeight->setValue(3);
    }
    else if(titlebarHeight <= 27)
    {
        m_dialog->titlebarHeight->setValue(4);
    }
    else if(titlebarHeight <= 31)
    {
        m_dialog->titlebarHeight->setValue(5);
    }
    else
    {
        m_dialog->titlebarHeight->setValue(6);
    }
}

void KindustrialConfig::save(KConfig*)
{
    m_config->setGroup("General");

    QRadioButton *button = (QRadioButton*)m_dialog->titleAlign->selected();
    if (button) m_config->writeEntry("TitleAlignment", QString(button->name()));

    m_config->writeEntry("UseTitleBarColor", m_dialog->designatedTitlebarColor->isChecked() );
    m_config->writeEntry("TitleShadow", m_dialog->titleShadow->isChecked() );
    m_config->writeEntry("ShrinkBorders", m_dialog->shrinkBorders->isChecked() );

    switch(m_dialog->titlebarHeight->value())
    {
        case 2:
            m_config->writeEntry("TitleHeightMin", 19 );
            break;
        case 3:
            m_config->writeEntry("TitleHeightMin", 23 );
            break;
        case 4:
            m_config->writeEntry("TitleHeightMin", 27 );
            break;
        case 5:
            m_config->writeEntry("TitleHeightMin", 31 );
            break;
        case 6:
            m_config->writeEntry("TitleHeightMin", 35 );
            break;
        case 1:
        default:
            m_config->writeEntry("TitleHeightMin", 16 );
    }
    m_config->sync();
}

void KindustrialConfig::defaults()
{
    QRadioButton *button =
        (QRadioButton*)m_dialog->titleAlign->child("AlignHCenter");
    if (button) button->setChecked(true);
    m_dialog->designatedTitlebarColor->setChecked(false);
    m_dialog->titleShadow->setChecked(true);
    m_dialog->shrinkBorders->setChecked(true);
    m_dialog->titlebarHeight->setValue(2);
}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

extern "C"
{
    QObject* allocate_config(KConfig* config, QWidget* parent) {
        return (new KindustrialConfig(config, parent));
    }
}

#include "config.moc"
