//////////////////////////////////////////////////////////////////////////////
// kindustrial.cpp
// -------------------
// Industrial inspired window decoration for KDE
// -------------------
// Copyright (c) 2003 Gregg Edghill
// Please see the header file for copyright and license information.
//////////////////////////////////////////////////////////////////////////////

#include <kconfig.h>
#include <kwin/workspace.h>
#include <kwin/options.h>

#include "kindustrial.h"
#include "kindustrial.moc"
#include "kindustrialclient.h"
#include "misc.h"

using namespace KWinInternal;

// static bool pixmaps_created = false;

bool KindustrialHandler::m_initialized    = false;
bool KindustrialHandler::m_useTitleColor  = false;
bool KindustrialHandler::m_titleShadow    = true;
bool KindustrialHandler::m_shrinkBorders  = true;
int  KindustrialHandler::m_borderSize     = 4; // do not change
int  KindustrialHandler::m_titleHeight    = 19;
int  KindustrialHandler::m_titleHeightTool= 12;
QFont KindustrialHandler::m_titleFont = QFont();
QFont KindustrialHandler::m_titleFontTool = QFont();
Qt::AlignmentFlags KindustrialHandler::m_titleAlign = Qt::AlignHCenter;

KindustrialHandler::KindustrialHandler()
{
    reset();
}

KindustrialHandler::~KindustrialHandler()
{
    m_initialized = false;
}

void KindustrialHandler::reset()
{
    m_titleFont = options->font(true, false);
    m_titleFontTool = m_titleFont;
    m_titleFontTool.setPointSize(m_titleFontTool.pointSize() - 3); // Shrink font by 3pt
    m_titleFontTool.setWeight( QFont::Normal ); // and disable bold

    // read in the configuration
    readConfig();

    // reset all clients
    Workspace::self()->slotResetAllClientsDelayed();
    m_initialized = true;
}

void KindustrialHandler::readConfig()
{
    // create a config object
    KConfig config("kwinkindustrialrc");
    config.setGroup("General");

    // grab settings
    m_titleShadow    = config.readBoolEntry("TitleShadow", true);
    m_shrinkBorders  = config.readBoolEntry("ShrinkBorders", true);
    //m_borderSize     = config.readNumEntry("BorderSize", 4);

    QFontMetrics fm(m_titleFont);  // active font = inactive font
    int titleHeightMin = config.readNumEntry("TitleHeightMin", 19);
    // The title should strech with bigger font sizes!
    m_titleHeight = QMAX(titleHeightMin, fm.height() + 4); // 4 px for the shadow etc.

    fm = QFontMetrics(m_titleFontTool);  // active font = inactive font
    int titleHeightToolMin = config.readNumEntry("TitleHeightToolMin", 13);
    // The title should strech with bigger font sizes!
    m_titleHeightTool = QMAX(titleHeightToolMin, fm.height() ); // don't care about the shadow etc.

    QString value = config.readEntry("TitleAlignment", "AlignHCenter");
    if (value == "AlignLeft")         m_titleAlign = Qt::AlignLeft;
    else if (value == "AlignHCenter") m_titleAlign = Qt::AlignHCenter;
    else if (value == "AlignRight")   m_titleAlign = Qt::AlignRight;

    m_useTitleColor = config.readBoolEntry("UseTitleBarColor", false);
}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

static KindustrialHandler *handler = 0;

extern "C"
{
    Client* allocate(Workspace *ws, WId w, int)
    {
        return new KindustrialClient(ws, w);
    }

    void init()
    {
        handler = new KindustrialHandler();
    }

    void reset()
    {
        handler->reset();
    }

    void deinit()
    {
         delete handler;
         handler = 0;
    }
}

// KindustrialHandler* clientHandler()
// {
//     return handler;
// }
