
//////////////////////////////////////////////////////////////////////////////
// kIndustrialButton.h
// -------------------
// Industrial inspired window decoration for KDE 3
// -------------------
// Copyright (c) 2003 Gregg Edghil <gs_edghill@hotmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//////////////////////////////////////////////////////////////////////////////

#ifndef KINDUSTRIALBUTTON_H
#define KINDUSTRIALBUTTON_H

#include <kwin/kwinbutton.h>

#include "kindustrial.h"

namespace KWinInternal {

	class KindustrialClient;

	class KindustrialButton : public KWinInternal::KWinButton
	{
		public:
    		KindustrialButton(KindustrialClient *parent=0, const char *name=0,
					  		  const QString &tip=NULL,
					  		  ButtonType type = ButtonHelp,
					  		  int size = 18);
    		~KindustrialButton();

    		void setSticky(bool sticky) { isSticky = sticky; repaint(false); }
    		void setMaximized(bool maximized) { isMaximized = maximized; repaint(false); }
    		QSize sizeHint() const; ///< Return size hint.
    		int lastMousePress() const { return m_lastMouse; }
    		void reset() { repaint(false); }
    		KindustrialClient * client() { return m_client; }

		private:
    		void enterEvent(QEvent *e);
    		void leaveEvent(QEvent *e);
			void mousePressEvent(QMouseEvent *e);
			void mouseReleaseEvent(QMouseEvent *e);
    		void drawButton(QPainter *painter);

		private:
    		KindustrialClient *m_client;
    		int m_lastMouse;

    		int m_size;

    		ButtonType m_type;
    		bool hover;
    		bool isSticky, isMaximized;
		};

} // namespace KWinInternal

#endif // KINDUSTRIALBUTTON_H
