
//////////////////////////////////////////////////////////////////////////////
// kIndustrialClient.h
// -------------------
// Industrial inspired window decoration for KDE 3
// -------------------
// Copyright (c) 2003 Gregg Edghil <gs_edghill@hotmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//////////////////////////////////////////////////////////////////////////////

#ifndef KINDUSTRIALCLIENT_H
#define KINDUSTRIALCLIENT_H

#include <kwin/client.h>
#include "kindustrial.h"

class QSpacerItem;
class QVBoxLayout;

namespace KWinInternal {

	class KindustrialButton;

	class KindustrialClient : public KWinInternal::Client
	{
    	Q_OBJECT
		public:
    		KindustrialClient(Workspace *ws, WId w, QWidget *parent = 0, const char *name = 0);
    		~KindustrialClient();

    		QPixmap getTitleBarTile(bool active) const
    		{
    		    return active ? *aTitleBarTile : *iTitleBarTile;
    		}
		protected:
    		virtual void resizeEvent(QResizeEvent *e);
    		virtual void paintEvent(QPaintEvent *e);
    		virtual void showEvent(QShowEvent *);
    		virtual void mouseDoubleClickEvent(QMouseEvent *e);
    		virtual void windowWrapperShowEvent(QShowEvent *);

    		virtual void maximizeChange(bool m);
    		virtual void doShape();

    		virtual void captionChange(const QString &name);
    		virtual void stickyChange(bool s);
    		virtual void iconChange();
    		virtual void activeChange(bool a);
    		virtual MousePosition mousePosition(const QPoint &point) const;

		private slots:
    		void maxButtonPressed();
    		void menuButtonPressed();
    		void menuButtonReleased();
		private:
    		void _resetLayout();
    		void addButtons(QBoxLayout* layout, const QString& buttons, int buttonSize = 18);

    		QVBoxLayout *mainLayout_;
    		QSpacerItem *topSpacer_,
                		*titleSpacer_,
                		*leftTitleSpacer_, *rightTitleSpacer_,
                		*decoSpacer_,
                		*leftSpacer_, *rightSpacer_,
                		*bottomSpacer_;

    		QPixmap *aCaptionBuffer, *iCaptionBuffer;
    		void update_captionBuffer();

    		QPixmap *aTitleBarTile, *iTitleBarTile;
    		bool pixmaps_created;
    		void create_pixmaps();
    		void delete_pixmaps();

    		KindustrialButton *m_button[ButtonTypeCount];

    		bool captionBufferDirty;
    		bool closing;

    		// settings...
    		int   s_titleHeight;
    		QFont s_titleFont;
	};

}

#endif // KINDUSTRIALCLIENT_H
